@@ -20,8 +20,8 @@ pub enum SfenError {
 
     #[error("an illegal board state notation is found")]
     IllegalBoardState,
-    
-    #[error("plynths can contain only knights")]
+
+    #[error("plinths can contain only knights")]
     IllegalPieceTypeOnPlynth,
 }
 
@@ -31,16 +31,19 @@ pub enum MoveError {
     #[error("the king is in check")]
     InCheck,
 
-    #[error("nifu detected")]
-    Nifu,
-
     #[error("perpetual check detected")]
     Draw,
 
+    #[error("stalemate detected")]
+    DrawByStalemate,
+
+    #[error("Insufficient material detected")]
+    DrawByInsufficientMaterial,
+
     #[error("not your turn")]
     EnemysTurn,
 
-    #[error("the piece can not move anymor")]
+    #[error("the piece can not move anymore")]
     NonMovablePiece,
 
     #[error("the move is inconsistent with the current position: {0}")]
