@@ -26,7 +26,7 @@ const ASCII_LOWER_L: u8 = b'l';
 /// assert_eq!(4, sq.file());
 /// assert_eq!(4, sq.rank());
 /// ```
-#[derive(Debug, PartialEq, Eq, Clone, Copy, Hash)]
+#[derive(Debug, Eq, Clone, Copy, Hash)]
 pub struct Square {
     inner: u8,
 }
@@ -59,7 +59,7 @@ impl Square {
         {
             return None;
         }
-        println!("{} , {}", bytes[0], ASCII_LOWER_A);
+        //println!("{} , {}", bytes[0], ASCII_LOWER_A);
         let file = bytes[0] - ASCII_LOWER_A;
         let _first = chars.nth(0).unwrap();
         let rank: String = chars.take(2).collect();
@@ -173,6 +173,12 @@ impl Square {
     }
 }
 
+impl PartialEq for Square {
+    fn eq(&self, other: &Self) -> bool {
+        self.inner == other.inner
+    }
+}
+
 impl fmt::Display for Square {
     fn fmt(&self, f: &mut fmt::Formatter) -> Result<(), fmt::Error> {
         debug_assert!(
@@ -284,7 +290,6 @@ mod tests {
                 "{} should cause an error",
                 case
             );
-            println!("okkk");
         }
     }
 
@@ -310,7 +315,6 @@ mod tests {
         for case in cases.iter() {
             let sq = Square::new(case.1, case.2).unwrap();
             assert_eq!(case.0, sq.to_string());
-            println!("okkk");
         }
     }
 }
